.. highlight:: shell

==============
List of tests
==============

Typically credit risk tests are specific to the model type and forecast period (typically 1-year vs multiyear period). The table below provides a simplified overview of all test that are part of this package. If you feel that some commonly used test is missing, please see section **Contributing** on how it can be added to the package.

For detailed information, see documentation of each test in **Individual tests > Documentation**.


.. csv-table:: 
   :file: tests.csv
   :widths: 10, 70, 30, 70
   :header-rows: 1

